@@ -10,10 +10,9 @@ import plotly as py
 import plotly.tools as tls 
 import matplotlib.pyplot as plt
 import seaborn as sns
-# %matplotlib inline
 import plotly.express as px
 from statistics import mean
-# output_notebook()
+output_notebook()
 
 class Calculator:
     def add_numbers(num1, num2):
@@ -31,3 +30,4 @@ class Calculator:
     def p():
         arr = np.random.normal(size=1000, loc=0, scale=1)
         return plot_hist(arr, bincount=50)
+
